@@ -2,7 +2,7 @@ import django_glue as dg
 from django.shortcuts import redirect, get_object_or_404
 from django.urls import reverse
 
-from django_spire.auth.group.decorators import permission_required
+from django_spire.auth.permissions.decorators import permission_required
 from django_spire.contrib.form.utils import show_form_errors
 from django_spire.contrib.generic_views import portal_views
 from django_spire.help_desk import forms
@@ -52,7 +52,7 @@ def ticket_update_form_view(request, pk: int):
         form = forms.HelpDeskTicketUpdateForm(request.POST, instance=ticket)
 
         if form.is_valid():
-            ticket.services.save_model_obj(**form.cleaned_data)
+            _, _ = ticket.services.save_model_obj(**form.cleaned_data)
 
             return redirect(reverse('django_spire:help_desk:page:list'))
 
