@@ -7,12 +7,12 @@ from django_spire.notification import models
 @admin.register(models.Notification)
 class NotificationAdmin(admin.ModelAdmin):
     list_display = (
-        'id', 'email', 'name', 'title', 'type', 'is_sent', 'send_datetime',
-        'sent_datetime', 'view_body_snippet', 'url_link'
+        'id', 'title', 'type', 'user', 'view_body_snippet', 'url_link', 'status',
+        'status_message', 'priority', 'sent_datetime', 'publish_datetime',
+        'content_type', 'object_id', 'is_deleted'
     )
-    list_filter = ('type', 'is_sent', 'send_datetime')
-    search_fields = ('id', 'email', 'name', 'title', 'type')
-    ordering = ('-send_datetime',)
+    list_filter = ('type',)
+    search_fields = ('id', 'title', 'type')
 
     def view_body_snippet(self, notification: models.Notification) -> str:
         return (
